#! /usr/bin/env python
## netconf - A switch printer tool
## Copyright (C) 2002 Red Hat, Inc.
## Copyright (C) 2002 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sys

PROGDIR = '/usr/share/redhat-switch-printer/'

if not "/usr/lib/rhs/python" in sys.path:
    sys.path.append("/usr/lib/rhs/python")

if not PROGDIR in sys.path:
    sys.path.append(PROGDIR)

import signal
import os
import os.path
import string
import gettext
from functions import *
from snack import *

##
## I18N
##
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)
_ = gettext.gettext


class mainDialog:
    def __init__(self):
        pass

    def main(self):
        self.hydrate()
        
    def hydrate(self):
        printer_list = get_printer()

        if len(printer_list) == 0:
            warningDialog()
            sys.exit(1)
            
        screen = SnackScreen()
        t = TextboxReflowed(45, TEXT)
        li = Listbox(5, width = 20, returnExit = 1)

        # add printer into listbox
        for printer in printer_list:
            if printer == PRINTER[LPRNG]:
                li.append('LPRng', LPRNG)
            if printer == PRINTER[CUPS]:
                li.append('CUPS', CUPS)

        # activate default printer
        printer = get_default_printer(printer_list)
        if printer == PRINTER[LPRNG]:
            li.setCurrent(LPRNG)
        elif printer == PRINTER[CUPS]:
            li.setCurrent(CUPS)

        # create button bar    
        bb = ButtonBar(screen, ((_('Ok'), 'ok'), (_('Cancel'), 'cancel')))

        g = GridForm(screen, TITLE, 1, 4)
        g.add(t, 0, 1)
        g.add(li, 0, 2, (0, 1, 0, 1))
        g.add(bb, 0, 3, growx = 1)

        result = g.runOnce()
        screen.finish()

        if bb.buttonPressed(result) != 'cancel':
            switch(li.current())
            self.infoDialog()

    def warningDialog(self):
        screen = SnackScreen()
        b =  Button(_('Ok'))
        t = TextboxReflowed(40, WARNING_TEXT+'\n\n')
        g = GridFormHelp(screen, _('Warning'), None, 1, 2)
        g.add(t, 0, 0)
        g.add(b, 0, 1)
    
        result = g.runOnce()
        screen.finish()

    def infoDialog(self):
        screen = SnackScreen()
        b =  Button(_('OK'))
        t = TextboxReflowed(45, INFO_TEXT1+'\n\n')
        g = GridFormHelp(screen, _('Information'), None, 1, 2)
        g.add(t, 0, 0)
        g.add(b, 0, 1)
    
        result = g.runOnce()
        screen.finish()


# make ctrl-C work
if __name__ == '__main__':
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    dlg = mainDialog().main()

    sys.exit(0)
